@@ -364,7 +364,7 @@ impl Web3 {
         let gas_limit = if let Some(gl) = gas_limit {
             gl
         } else {
-            let gas = simulated_gas_price_and_limit(our_balance.clone());
+            let gas = self.simulated_gas_price_and_limit(our_balance.clone()).await?;
             self.eth_estimate_gas(TransactionRequest {
                 from: Some(own_address),
                 to: to_address,
@@ -425,7 +425,7 @@ impl Web3 {
 
         let payload = encode_call(sig, tokens)?;
 
-        let gas = simulated_gas_price_and_limit(our_balance);
+        let gas = self.simulated_gas_price_and_limit(our_balance).await?;
         let transaction = TransactionRequest {
             from: Some(own_address),
             to: contract_address,
@@ -495,6 +495,57 @@ impl Web3 {
             }
         }
     }
+
+    /// Geth and parity behave differently for the Estimate gas call or eth_call()
+    /// Parity / OpenEthereum will allow you to specify no gas price
+    /// and no gas amount the estimate gas call will then return the
+    /// amount of gas the transaction would take. This is reasonable behavior
+    /// from an endpoint that's supposed to let you estimate gas usage
+    ///
+    /// The gas price is of course irrelevant unless someone goes out of their
+    /// way to design a contract that fails a low gas prices. Geth and Parity
+    /// can't simulate an actual transaction market accurately.
+    ///
+    /// Geth on the other hand insists that you provide a gas price of at least
+    /// 7 post London hardfork in order to respond. This seems to be because Geth
+    /// simply tosses your transaction into the actual execution code, so no gas
+    /// instantly fails.
+    ///
+    /// If this value is too low Geth will fail, if this value is higher than
+    /// your balance Geth will once again fail. So Geth at this juncture won't
+    /// tell you what the transaction would cost, just that you can't afford it.
+    ///
+    /// Max possible gas price is Uint 32 max, Geth will print warnings above 25mil
+    /// gas.
+    ///
+    /// This function will navigate all these restrictions in order to give you the
+    /// maximum valid gas possible for any simulated call
+    async fn simulated_gas_price_and_limit(
+        &self,
+        balance: Uint256,
+    ) -> Result<SimulatedGas, Web3Error> {
+        let block = self.eth_get_latest_block().await;
+        let test = self.xdai_get_latest_block().await;
+        // handle the xdai case, at least until xDai upgrades to London, this is needed
+        // because getting the eth block may fail spuriously on xdai
+        if block.is_err() && test.is_ok() {
+            let price: Uint256 = 1u8.into();
+            let limit = min(25_000_000u128.into(), balance / price.clone());
+            return Ok(SimulatedGas { limit, price });
+        }
+
+        // we are on Eth, now we need to see if it's pre or post London
+        let block = block?;
+        let price = if let Some(base_gas) = block.base_fee_per_gas {
+            // post London
+            base_gas
+        } else {
+            // pre London
+            1u8.into()
+        };
+        let limit = min(25_000_000u128.into(), balance / price.clone());
+        Ok(SimulatedGas { limit, price })
+    }
 }
 
 struct SimulatedGas {
@@ -502,36 +553,6 @@ struct SimulatedGas {
     price: Uint256,
 }
 
-// Geth and parity behave differently for the Estimate gas call or eth_call()
-// Parity / OpenEthereum will allow you to specify no gas price
-// and no gas amount the estimate gas call will then return the
-// amount of gas the transaction would take. This is reasonable behavior
-// from an endpoint that's supposed to let you estimate gas usage
-//
-// The gas price is of course irrelevant unless someone goes out of their
-// way to design a contract that fails a low gas prices. Geth and Parity
-// can't simulate an actual transaction market accurately.
-//
-// Geth on the other hand insists that you provide a gas price of at least
-// 7 post London hardfork in order to respond. This seems to be because Geth
-// simply tosses your transaction into the actual execution code, so no gas
-// instantly fails.
-//
-// If this value is too low Geth will fail, if this value is higher than
-// your balance Geth will once again fail. So Geth at this juncture won't
-// tell you what the transaction would cost, just that you can't afford it.
-//
-// Max possible gas price is Uint 32 max, Geth will print warnings above 25mil
-// gas.
-//
-// This function will navigate all these restrictions in order to give you the
-// maximum valid gas possible for any simulated call
-fn simulated_gas_price_and_limit(balance: Uint256) -> SimulatedGas {
-    let price: Uint256 = 10u8.into();
-    let limit = min(25_000_000u128.into(), balance / price.clone());
-    SimulatedGas { limit, price }
-}
-
 #[test]
 fn test_chain_id() {
     use actix::System;
